@@ -1,7 +1,7 @@
 # Based on https://github.com/KiCad/kicad-source-mirror/blob/master/demos/python_scripts_examples/gen_gerber_and_drill_files_board.py
 import sys
 import os
-from kikit.pcbnew_compatibility import pcbnew
+from pcbnewTransition import pcbnew
 from pcbnew import *
 
 fullGerberPlotPlan = [
@@ -19,13 +19,14 @@ fullGerberPlotPlan = [
 ]
 
 exportSettingsJlcpcb = {
-    "UseGerberProtelExtensions": False,
-    "UseAuxOrigin": True,
-    "ExcludeEdgeLayer": False,
+    "UseGerberProtelExtensions": True,
+    "UseAuxOrigin": False,
+    "ExcludeEdgeLayer": True,
     "MinimalHeader": False,
     "NoSuffix": False,
     "MergeNPTH": True,
     "ZerosFormat": GENDRILL_WRITER_BASE.DECIMAL_FORMAT,
+    "SubstractMaskFromSilk": True
 }
 
 exportSettingsPcbway = {
@@ -38,6 +39,16 @@ exportSettingsPcbway = {
     "ZerosFormat": GENDRILL_WRITER_BASE.SUPPRESS_LEADING,
 }
 
+exportSettingsOSHPark = {
+    "UseGerberProtelExtensions": True,
+    "UseAuxOrigin": False,
+    "ExcludeEdgeLayer": True,
+    "MinimalHeader": False,
+    "NoSuffix": False,
+    "MergeNPTH": True,
+    "ZerosFormat": GENDRILL_WRITER_BASE.DECIMAL_FORMAT,
+}
+
 
 def hasCopper(plotPlan):
     for _, layer, _ in plotPlan:
@@ -96,7 +107,6 @@ def gerberImpl(boardfile, outputdir, plot_plan=fullGerberPlotPlan, drilling=True
         pctl.SetLayer(id)
         suffix = "" if settings["NoSuffix"] else name
         pctl.OpenPlotfile(suffix, PLOT_FORMAT_GERBER, comment)
-        print('plot {}'.format(pctl.GetPlotFileName()))
         jobfile_writer.AddGbrFile(id, os.path.basename(pctl.GetPlotFileName()))
         if pctl.PlotLayer() == False:
             print("plot error")
@@ -107,9 +117,9 @@ def gerberImpl(boardfile, outputdir, plot_plan=fullGerberPlotPlan, drilling=True
         for innerlyr in range (1, lyrcnt - 1):
             popt.SetSkipPlotNPTH_Pads(True)
             pctl.SetLayer(innerlyr)
-            lyrname = 'inner{}'.format(innerlyr)
+            lyrname = "" if settings["NoSuffix"] else 'inner{}'.format(innerlyr)
             pctl.OpenPlotfile(lyrname, PLOT_FORMAT_GERBER, "inner")
-            print('plot {}'.format(pctl.GetPlotFileName()))
+            jobfile_writer.AddGbrFile(innerlyr, os.path.basename(pctl.GetPlotFileName()))
             if pctl.PlotLayer() == False:
                 print("plot error")
 
@@ -125,7 +135,11 @@ def gerberImpl(boardfile, outputdir, plot_plan=fullGerberPlotPlan, drilling=True
 
         mirror = False
         minimalHeader = settings["MinimalHeader"]
-        offset = board.GetDesignSettings().m_AuxOrigin
+        if settings["UseAuxOrigin"]:
+            offset = board.GetDesignSettings().GetAuxOrigin()
+        else:
+            offset = wxPoint(0,0)
+
         # False to generate 2 separate drill files (one for plated holes, one for non plated holes)
         # True to generate only one drill file
         mergeNPTH = settings["MergeNPTH"]
@@ -137,17 +151,14 @@ def gerberImpl(boardfile, outputdir, plot_plan=fullGerberPlotPlan, drilling=True
         drlwriter.SetFormat(metricFmt, zerosFmt)
         genDrl = True
         genMap = True
-        print('create drill and map files in {}'.format(pctl.GetPlotDirName()))
         drlwriter.CreateDrillandMapFilesSet(pctl.GetPlotDirName(), genDrl, genMap)
 
         # One can create a text file to report drill statistics
         rptfn = pctl.GetPlotDirName() + 'drill_report.rpt'
-        print('report: {}'.format(rptfn))
         drlwriter.GenDrillReportFile(rptfn)
 
     job_fn=os.path.dirname(pctl.GetPlotFileName()) + '/' + os.path.basename(boardfile)
     job_fn=os.path.splitext(job_fn)[0] + '.gbrjob'
-    print('create job file {}'.format(job_fn))
     jobfile_writer.CreateJobFile(job_fn)
 
 def pasteDxfExport(board, plotDir):
