@@ -1,27 +1,33 @@
-from kikit import pcbnew_compatibility
+
+from pcbnewTransition import KICAD_VERSION, isV6
+from kikit.common import KIKIT_LIB
 import sys
 import click
 
-version = pcbnew_compatibility.getVersion()
-
-
 @click.command()
 def kicadversion():
     """
     Return version of KiCAD
     """
-    print(f"{version[0]}.{version[1]}")
+    print(f"{KICAD_VERSION[0]}.{KICAD_VERSION[1]}")
 
 @click.command()
 def drcapi():
     """
     Return version of the DRC API
     """
-    if pcbnew_compatibility.isV6(version):
+    if isV6():
         print("1")
     else:
         print("0")
 
+@click.command()
+def lib():
+    """
+    Return KiKit library location
+    """
+    print(KIKIT_LIB)
+
 
 @click.group()
 def cli():
@@ -31,4 +37,5 @@ def cli():
     pass
 
 cli.add_command(kicadversion)
-cli.add_command(drcapi)
\ No newline at end of file
+cli.add_command(drcapi)
+cli.add_command(lib)
\ No newline at end of file
