@@ -1,10 +1,14 @@
-from kikit.pcbnew_compatibility import pcbnew
+from pcbnewTransition import pcbnew
 from pcbnew import wxPoint
 import numpy as np
+import json
+from collections import OrderedDict
+from pcbnewTransition.transition import isV6
 from kikit.common import *
 from kikit.defs import *
 from kikit.substrate import Substrate, extractRings, toShapely, linestringToKicad
 from kikit.export import gerberImpl, pasteDxfExport
+from kikit.export import exportSettingsJlcpcb
 import solid
 import solid.utils
 import subprocess
@@ -28,11 +32,21 @@ def addRoundedCorner(board, center, start, end, thickness):
     corner = pcbnew.PCB_SHAPE()
     corner.SetShape(STROKE_T.S_ARC)
     corner.SetCenter(wxPoint(center[0], center[1]))
-    corner.SetArcStart(wxPoint(start[0], start[1]))
-    if np.cross(start - center, end - center) > 0:
-        corner.SetAngle(fromDegrees(90))
+    if isV6():
+        corner.SetStart(wxPoint(start[0], start[1]))
     else:
-        corner.SetAngle(fromDegrees(-90))
+        corner.SetArcStart(wxPoint(start[0], start[1]))
+
+    if np.cross(start - center, end - center) > 0:
+        if isV6():
+            corner.SetArcAngleAndEnd(fromDegrees(90), True)
+        else:
+            corner.SetAngle(fromDegrees(90))
+    else:
+        if isV6():
+            corner.SetArcAngleAndEnd(fromDegrees(-90), True)
+        else:
+            corner.SetAngle(fromDegrees(-90))
     corner.SetWidth(thickness)
     corner.SetLayer(Layer.F_Paste)
     board.Add(corner)
@@ -122,7 +136,11 @@ def addHole(board, position, radius):
     circle = pcbnew.PCB_SHAPE()
     circle.SetShape(STROKE_T.S_CIRCLE)
     circle.SetCenter(wxPoint(position[0], position[1]))
-    circle.SetArcStart(wxPoint(position[0], position[1]) + wxPoint(radius/2, 0))
+    if isV6():
+        # Set 3'oclock point of the circle to set radius
+        circle.SetEnd(wxPoint(position[0], position[1]) + wxPoint(radius/2, 0))
+    else:
+        circle.SetArcStart(wxPoint(position[0], position[1]) + wxPoint(radius/2, 0))
     circle.SetWidth(radius)
     circle.SetLayer(Layer.F_Paste)
     board.Add(circle)
@@ -182,7 +200,7 @@ def createOuterPolygon(board, jigFrameSize, outerBorder):
     outerSubstrate.substrates = outerSubstrate.substrates.buffer(outerBorder)
     tabs = []
     for hole in holes:
-        tab, _ = outerSubstrate.tab(hole, centerpoint - hole, INNER_BORDER, fromMm(1000))
+        tab, _ = outerSubstrate.tab(hole, centerpoint - hole, INNER_BORDER, maxHeight=fromMm(1000))
         tabs.append(tab)
     outerSubstrate.union(tabs)
     outerSubstrate.union([Point(x).buffer(INNER_BORDER / 2) for x in holes])
@@ -246,7 +264,6 @@ def makeTopRegister(board, jigFrameSize, jigThickness, pcbThickness,
     """
     Create a SolidPython representation of the top register
     """
-    print("Top")
     return makeRegister(board, jigFrameSize, jigThickness, pcbThickness,
             outerBorder, innerBorder, tolerance, True)
 
@@ -256,18 +273,27 @@ def makeBottomRegister(board, jigFrameSize, jigThickness, pcbThickness,
     """
     Create a SolidPython representation of the top register
     """
-    print("Bottom")
     return makeRegister(board, jigFrameSize, jigThickness, pcbThickness,
             outerBorder, innerBorder, tolerance, False)
 
 def renderScad(infile, outfile):
     infile = os.path.abspath(infile)
     outfile = os.path.abspath(outfile)
-    subprocess.check_call(["openscad", "-o", outfile, infile])
+    try:
+        subprocess.run(["openscad", "-o", outfile, infile],
+            stdout=subprocess.PIPE, stderr=subprocess.PIPE, check=True)
+    except subprocess.CalledProcessError as e:
+        message = f"Cannot render {outfile}, OpenSCAD error:\n"
+        message += (e.stdout.decode("utf-8") + "\n") if e.stdout is not None else ""
+        message += (e.stderr.decode("utf-8") + "\n") if e.stderr is not None else ""
+        raise RuntimeError(message)
+    except FileNotFoundError as e:
+        message = f"OpenSCAD is not available.\n"
+        message += f"Did you install it? Program `openscad` has to be in PATH"
+        raise RuntimeError(message)
 
 def shapelyToSHAPE_POLY_SET(polygon):
     p = pcbnew.SHAPE_POLY_SET()
-    print(polygon.exterior)
     p.AddOutline(linestringToKicad(polygon.exterior))
     return p
 
@@ -287,6 +313,44 @@ def cutoutComponents(board, components):
         zone.SetLayer(Layer.B_Paste)
         board.Add(zone)
 
+def setStencilLayerVisibility(boardName):
+    if not isV6():
+        return
+    prlPath = os.path.splitext(boardName)[0] + ".kicad_prl"
+    with open(prlPath) as f:
+        # We use ordered dict, so we preserve the ordering of the keys and
+        # thus, formatting
+        prl = json.load(f, object_pairs_hook=OrderedDict)
+    prl["board"]["visible_layers"] = "ffc000c_7ffffffe"
+    prl["board"]["visible_items"] = [
+        1,
+        2,
+        3,
+        4,
+        9,
+        10,
+        12,
+        13,
+        15,
+        16,
+        19,
+        21,
+        22,
+        24,
+        25,
+        26,
+        27,
+        28,
+        29,
+        30,
+        32,
+        33,
+        34,
+        35
+    ]
+    with open(prlPath, "w") as f:
+        json.dump(prl, f, indent=2)
+    pass
 
 from pathlib import Path
 import os
@@ -306,13 +370,19 @@ def create(inputboard, outputdir, jigsize, jigthickness, pcbthickness,
     stencilFile = os.path.join(outputdir, "stencil.kicad_pcb")
     board.Save(stencilFile)
 
+    setStencilLayerVisibility(stencilFile)
+
     plotPlan = [
         # name, id, comment
         ("PasteBottom", pcbnew.B_Paste, "Paste Bottom"),
         ("PasteTop", pcbnew.F_Paste, "Paste top"),
     ]
+    # get a copy of exportSettingsJlcpcb dictionary and
+    # exclude the Edge.Cuts layer for creation of stencil gerber files
+    exportSettings = exportSettingsJlcpcb.copy()
+    exportSettings["ExcludeEdgeLayer"] = True
     gerberDir = os.path.join(outputdir, "gerber")
-    gerberImpl(stencilFile, gerberDir, plotPlan, False)
+    gerberImpl(stencilFile, gerberDir, plotPlan, False, exportSettings)
     gerbers = [os.path.join(gerberDir, x) for x in os.listdir(gerberDir)]
     subprocess.check_call(["zip", "-j",
         os.path.join(outputdir, "gerbers.zip")] + gerbers)
@@ -401,6 +471,13 @@ def createPrinted(inputboard, outputdir, pcbthickness, thickness, framewidth,
     # versions.
     height = min(pcbthickness, max(0.5, pcbthickness - 0.3))
     bottomPaste, topPaste, outline = pasteDxfExport(board, outputdir)
+    # On Windows, OpenSCAD requires to use forward slashes instead of backslashes,
+    # hence, the replacement:
+    if os.name == "nt":
+        bottomPaste = bottomPaste.replace("\\", "/")
+        topPaste = topPaste.replace("\\", "/")
+        outline = outline.replace("\\", "/")
+
     topCutout = extractComponentPolygons(cutoutComponents, "F.CrtYd")
     bottomCutout = extractComponentPolygons(cutoutComponents, "B.CrtYd")
     topStencil = printedStencil(outline, topPaste, topCutout, thickness, height,
